# eric7.Plugins.WizardPlugins.SetupWizard.AddProjectUrlDialog

Module implementing a dialog to enter the data for a project URL.

### Global Attributes

None

### Classes

AddProjectUrlDialog | Class implementing a dialog to enter the data for a project URL.

### Functions

None

## AddProjectUrlDialog

Class implementing a dialog to enter the data for a project URL.

### Derived from

QDialog, Ui_AddProjectUrlDialog

### Class Attributes

None

### Class Methods

None

### Methods

AddProjectUrlDialog | Constructor
__updateOK | Private slot to update the enabled state of the OK button.
getUrl | Public method to get the data for the project URL.

### Static Methods

None

#### AddProjectUrlDialog (Constructor)

AddProjectUrlDialog(name="", url="", parent=None)

Constructor

name (str (optional))
  name of the project URL (defaults to "")
url (str (optional))
  address of the project URL (defaults to "")
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### AddProjectUrlDialog.__updateOK

__updateOK()

Private slot to update the enabled state of the OK button.

#### AddProjectUrlDialog.getUrl

getUrl()

Public method to get the data for the project URL.

Return:
  tuple containing the name and address of the project URL

Return Type:
  tuple of (str, str)

Up